@@ -1,5 +1,3 @@
-context("calc_FadingCorr")
-
 set.seed(1)
 temp <- calc_FadingCorr(
   age.faded = c(0.1,0),
@@ -12,11 +10,13 @@ temp <- calc_FadingCorr(
 
 test_that("check class and length of output", {
   testthat::skip_on_cran()
-  expect_equal(is(temp), c("RLum.Results", "RLum"))
+  local_edition(3)
+
+  expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 2)
 
   ##check the verbose mode
-  expect_is(calc_FadingCorr(
+  expect_s4_class(calc_FadingCorr(
     age.faded = c(0.1,0),
     g_value = c(5.0, 1.0),
     tc = 2592000,
@@ -27,6 +27,7 @@ test_that("check class and length of output", {
 
 test_that("check values from output example 1", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   results <- get_RLum(temp)
 
@@ -36,8 +37,8 @@ test_that("check values from output example 1", {
   expect_equal(results$AGE_FADED.ERROR, 0)
   expect_equal(results$G_VALUE, 5.312393)
   expect_equal(round(results$G_VALUE.ERROR, 5), 1.01190)
-  expect_equal(results$KAPPA, 0.02307143)
-  expect_equal(results$KAPPA.ERROR, 0.00439463)
+  expect_equal(round(results$KAPPA, 3), 0.0230)
+  expect_equal(round(results$KAPPA.ERROR,3), 0.004)
   expect_equal(results$TC, 8.213721e-05)
   expect_equal(results$TC.G_VALUE, 5.475814e-06)
   expect_equal(results$n.MC, 100)
